@@ -304,8 +304,8 @@ class Engine(Broker):
             point = datetime.strptime(initial_time,dateformat)
             dataindex = self.data.index
             dataindex = pd.to_datetime(dataindex,dayfirst=True,format=dateformat)
-            diffs = np.array(list(dataindex)) - point
-            value = np.absolute(diffs).min()
+            diffs = np.absolute(np.array(list(dataindex)) - point)
+            value = diffs.min()
             initial = list(np.where(diffs==value)[0])[0]
             print(f"New origin: {dataindex[initial]}")
             converted = True
